import Card from "../card";
import { DeckOptions } from "./deck.interface";
/**
 * Represents a deck of playing cards.
 */
export default class Deck {
    private deck;
    private drawCards;
    /**
     * Represents a deck of cards.
     * @constructor
     * @param options - The options for initializing the deck.
     * @param options.deck - The deck of cards to use.
     * @param options.withJokers - Whether to include jokers in the deck. Default is false.
     */
    constructor(options?: DeckOptions);
    /**
     * Retrieves the deck of cards.
     * @returns {Card[]} The deck of cards.
     */
    getDeck(): Card[];
    /**
     * Initializes the deck with the specified options or creates a new deck if no options are provided.
     * @param options - The options to initialize the deck with.
     * @param options.deck - The deck of cards to use.
     * @param options.withJokers - Whether to include jokers in the deck. Default is false.
     * @returns The initialized deck.
     */
    private initDeck;
    /**
     * Resets the deck by reinitializing it with a standard set of playing cards.
     * @returns The current instance of the Deck class.
     */
    resetDeck(): Deck;
    /**
     * Shuffles the deck by swapping random cards multiple times.
     * @param nbShuffleTime The number of times to shuffle the deck. Default is 1000.
     * @returns The updated Deck instance with the shuffled deck.
     */
    shuffleDeck(nbShuffleTime?: number): this;
    /**
     * Draws a card from the deck and adds it to the drawCards array.
     * @returns {Card | undefined} The card that was drawn from the deck, or undefined if the deck is empty.
     */
    drawCard(): Card | undefined;
}
